@@ -16,11 +16,11 @@ class FlowiaRmq:
           self._connection = await aio_pika.connect_robust(url)
           self._channel = await self._connection.channel()
 
-     async def channel_declare(self , topic_name):
-         await self._channel.declare_exchange(topic_name , 'fanout')
+     async def topic_declare(self , topic_name):
+         await self._channel.declare_exchange(topic_name , 'fanout',durable=True)
  
      async def publish(self ,topic_name , message:FlowiaRmqBaseModel , event ):
-          exchange = await self._channel.declare_exchange(topic_name, type="fanout")
+          exchange = await self._channel.declare_exchange(topic_name, type="fanout",durable=True)
           await exchange.publish(
                aio_pika.Message(
                bytes(json.dumps(message.dict()) , "utf-8"),
@@ -29,6 +29,7 @@ class FlowiaRmq:
                ),routing_key="")
 
      async def  subscribe(self ,topic_name ,callback, events=[] ) :
+          await self._channel.declare_exchange(topic_name, type="fanout",durable=True)
           queue = await self._channel.declare_queue('', auto_delete=True)
           queue_name = queue.name
           await queue.bind(topic_name , queue_name)
